@@ -5,13 +5,13 @@ This module stores some commonly used mathematical physical equations, laws, mat
 '''
 
 import numpy as np
-from maysics import operator
+from maysics.calculus import Del
 from maysics import constant
 from scipy.integrate import solve_ivp
 from scipy.sparse import csr_matrix
 
 
-class Fouriers_law(operator.Del):
+class Fouriers_law(Del):
     '''
     傅里叶定律/热传导定律
     热流量：J=-k▽T
@@ -45,7 +45,7 @@ class Fouriers_law(operator.Del):
         ---------
         T: temperature distribution function
         '''
-        j = operator.Del.grad(self, T)
+        j = Del.grad(self, T)
         def j2(x):
             j1 = -self.k * j(x)
             return j1
